aboutsummaryrefslogtreecommitdiff
path: root/kokoro
diff options
context:
space:
mode:
authorambrosin <ambrosin@google.com>2023-04-25 06:56:53 -0700
committerCopybara-Service <copybara-worker@google.com>2023-04-25 06:58:06 -0700
commit411e3cfce3219224f5916690f731112ab3751850 (patch)
tree005f4ecba18a90551e969a221c80de1c82fe1c8d /kokoro
parentbc708f319491eadd300e8e4d17e307075cdfc8bc (diff)
downloadtink-411e3cfce3219224f5916690f731112ab3751850.tar.gz
Set minimum supported CMake version to 3.13
The current minimum supported version in https://github.com/google/oss-policies-info/blob/main/foundational-cxx-support-matrix.md is 3.10, but this is going to change to 3.13 from May 1st because Ubuntu 18.04 will be no longer supoported. 3.13 is the older version that comes packaged with the supported distros (Debian 10 in this case). See https://opensource.google/documentation/policies/cplusplus-support#support_criteria_3 PiperOrigin-RevId: 526954498
Diffstat (limited to 'kokoro')
-rw-r--r--kokoro/gcp_ubuntu_per_language/cc/cmake/run_tests.sh6
-rw-r--r--kokoro/gcp_ubuntu_per_language/cc/examples/cmake/run_tests.sh6
2 files changed, 6 insertions, 6 deletions
diff --git a/kokoro/gcp_ubuntu_per_language/cc/cmake/run_tests.sh b/kokoro/gcp_ubuntu_per_language/cc/cmake/run_tests.sh
index 0b6d8e751..8ca461863 100644
--- a/kokoro/gcp_ubuntu_per_language/cc/cmake/run_tests.sh
+++ b/kokoro/gcp_ubuntu_per_language/cc/cmake/run_tests.sh
@@ -22,7 +22,7 @@ fi
./kokoro/testutils/upgrade_gcc.sh
# Sourcing is needed to update the caller environment.
-# Install CMake 3.10 which is the minimum required.
-source ./kokoro/testutils/install_cmake.sh "3.10.0" \
- "6b5ea290042fac96023fd5387cd65cc69fdf4f48bad91177eb8697ba37e3deb3"
+# Install CMake 3.13 which is the minimum required.
+source ./kokoro/testutils/install_cmake.sh "3.13.5" \
+ "e2fd0080a6f0fc1ec84647acdcd8e0b4019770f48d83509e6a5b0b6ea27e5864"
./kokoro/testutils/run_cmake_tests.sh .
diff --git a/kokoro/gcp_ubuntu_per_language/cc/examples/cmake/run_tests.sh b/kokoro/gcp_ubuntu_per_language/cc/examples/cmake/run_tests.sh
index b1a8dbaca..b9f6ea116 100644
--- a/kokoro/gcp_ubuntu_per_language/cc/examples/cmake/run_tests.sh
+++ b/kokoro/gcp_ubuntu_per_language/cc/examples/cmake/run_tests.sh
@@ -22,9 +22,9 @@ fi
./kokoro/testutils/upgrade_gcc.sh
# Sourcing is needed to update the caller environment.
-# Install CMake 3.10 which is the minimum required.
-source ./kokoro/testutils/install_cmake.sh "3.10.0" \
- "6b5ea290042fac96023fd5387cd65cc69fdf4f48bad91177eb8697ba37e3deb3"
+# Install CMake 3.13 which is the minimum required.
+source ./kokoro/testutils/install_cmake.sh "3.13.5" \
+ "e2fd0080a6f0fc1ec84647acdcd8e0b4019770f48d83509e6a5b0b6ea27e5864"
./kokoro/testutils/run_cmake_tests.sh "cc/examples" -DTINK_BUILD_TESTS=OFF